==> haskell-type-hint-0.1-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-type-hint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: type-hint
version: 0.1
id: type-hint-0.1-BZHH0UJkhgC2RXAa9JWu8V
key: type-hint-0.1-BZHH0UJkhgC2RXAa9JWu8V
license: BSD-3-Clause
copyright: 2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/type-hint
synopsis: Guide type inference with proxy values
description:
    This package provides '\''Proxy'\'' values for various types from the @base@
    library and functions to use these values as hints for type inference.
category: Phantom Types
abi: 244e87e321dedccf46bac87289277c98
exposed: True
exposed-modules:
    Type.Hint
import-dirs: /usr/lib/ghc-8.4.3/site-local/type-hint-0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/type-hint-0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/type-hint-0.1
hs-libraries: HStype-hint-0.1-BZHH0UJkhgC2RXAa9JWu8V
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
haddock-interfaces: /usr/share/doc/haskell-type-hint/html/type-hint.haddock
haddock-html: /usr/share/doc/haskell-type-hint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-type-hint-0.1-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-type-hint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: type-hint
version: 0.1
id: type-hint-0.1-HP8tKFGSWNP9WW8dks9Xp0
key: type-hint-0.1-HP8tKFGSWNP9WW8dks9Xp0
license: BSD-3-Clause
copyright: 2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/type-hint
synopsis: Guide type inference with proxy values
description:
    This package provides '\''Proxy'\'' values for various types from the @base@
    library and functions to use these values as hints for type inference.
category: Phantom Types
abi: bf469044e1f963593a12dde7419fb788
exposed: True
exposed-modules:
    Type.Hint
import-dirs: /usr/lib/ghc-8.6.2/site-local/type-hint-0.1
library-dirs: /usr/lib/ghc-8.6.2/site-local/type-hint-0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/type-hint-0.1
hs-libraries: HStype-hint-0.1-HP8tKFGSWNP9WW8dks9Xp0
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-type-hint/html/type-hint.haddock
haddock-html: /usr/share/doc/haskell-type-hint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
